==> gitlab_16.11.6.orig.tar.bz2: gitlab-foss-v16.11.6/app/assets/javascripts/organizations/mock_projects.js <==
/* eslint-disable @gitlab/require-i18n-strings */

// This is temporary mock data that will be removed when completing the following:
// https://gitlab.com/gitlab-org/gitlab/-/issues/420777
// https://gitlab.com/gitlab-org/gitlab/-/issues/421441

export const organizationProjects = [
  {
    id: 'gid://gitlab/Project/8',
    fullPath: 'project/8',
    nameWithNamespace: 'Twitter / Typeahead.Js',
    organizationEditPath: '/-/organizations/default/projects/twitter/Typeahead.Js/edit',
    webUrl: 'http://127.0.0.1:3000/twitter/Typeahead.Js',
    topics: ['JavaScript', 'Vue.js', 'GraphQL', 'Jest', 'CSS', 'HTML'],
    forksCount: 4,
    avatarUrl: null,
    starCount: 0,
    visibility: 'public',
    openMergeRequestsCount: 5,
    openIssuesCount: 48,
    descriptionHtml:
      '<p data-sourcepos="1:1-1:59" dir="auto">Optio et reprehenderit enim doloremque deserunt et commodi. Sed sit amet iaculis neque. Morbi vel convallis elit. Aliquam vitae arcu orci. Aenean sem velit, dapibus eget enim id, tempor lobortis orci. Pellentesque dignissim nec velit eget sagittis. Maecenas lectus sapien, tincidunt ac cursus a, aliquam eu ipsum. Aliquam posuere maximus augue, ut vehicula elit vulputate condimentum. In libero leo, vehicula nec risus in, ullamcorper convallis risus. Phasellus sit amet lectus sit amet sem volutpat cursus. Nullam facilisis nulla nec lacus pretium, in pretium ex aliquam.</p>',
    archived: false,
    mergeRequestsAccessLevel: {
      stringValue: 'ENABLED',
    },
    issuesAccessLevel: {
      stringValue: 'ENABLED',
    },
    forkingAccessLevel: {
      stringValue: 'ENABLED',
    },
    userPermissions: {
      removeProject: true,
      viewEditPage: true,
    },
    maxAccessLevel: {
      integerValue: 30,
    },
    __typename: 'Project',
  },
  {
    id: 'gid://gitlab/Project/7',
    fullPath: 'project/7',
    nameWithNamespace: 'Flightjs / Flight',
    organizationEditPath: '/-/organizations/default/projects/flightjs/Flight/edit',
    webUrl: 'http://127.0.0.1:3000/flightjs/Flight',
    topics: [],
    forksCount: 0,
    avatarUrl: null,
    starCount: 0,
    visibility: 'private',
    openMergeRequestsCount: 10,
    openIssuesCount: 37,
    descriptionHtml:
      '<p data-sourcepos="1:1-1:49" dir="auto">Dolor dicta rerum et ut eius voluptate earum qui.</p>',
    archived: false,
    mergeRequestsAccessLevel: {
      stringValue: 'ENABLED',
    },
    issuesAccessLevel: {
      stringValue: 'ENABLED',
    },
    forkingAccessLevel: {
      stringValue: 'ENABLED',
    },
    userPermissions: {
      removeProject: true,
      viewEditPage: true,
    },
    maxAccessLevel: {
      integerValue: 30,
    },
    __typename: 'Project',
  },
  {
    id: 'gid://gitlab/Project/6',
    fullPath: 'project/6',
    nameWithNamespace: 'Jashkenas / Underscore',
    organizationEditPath: '/-/organizations/default/projects/jashkenas/Underscore/edit',
    webUrl: 'http://127.0.0.1:3000/jashkenas/Underscore',
    topics: [],
    forksCount: 0,
    avatarUrl: null,
    starCount: 0,
    visibility: 'private',
    openMergeRequestsCount: 0,
    openIssuesCount: 34,
    descriptionHtml:
      '<p data-sourcepos="1:1-1:52" dir="auto">Incidunt est aliquam autem nihil eveniet quis autem.</p>',
    archived: false,
    mergeRequestsAccessLevel: {
      stringValue: 'ENABLED',
    },
    issuesAccessLevel: {
      stringValue: 'ENABLED',
    },
    forkingAccessLevel: {
      stringValue: 'ENABLED',
    },
    userPermissions: {
      removeProject: true,
      viewEditPage: true,
    },
    maxAccessLevel: {
      integerValue: 30,
    },
    __typename: 'Project',
  },
  {
    id: 'gid://gitlab/Project/5',
    fullPath: 'project/5',
    nameWithNamespace: 'Commit451 / Lab Coat',
    organizationEditPath: '/-/organizations/default/projects/Commit451/lab-coat/edit',
    webUrl: 'http://127.0.0.1:3000/Commit451/lab-coat',
    topics: [],
    forksCount: 0,
    avatarUrl: null,
    starCount: 0,
    visibility: 'internal',
    openMergeRequestsCount: 3,
    openIssuesCount: 49,
    descriptionHtml:
      '<p data-sourcepos="1:1-1:34" dir="auto">Sint eos dolorem impedit rerum et.</p>',
    archived: true,
    mergeRequestsAccessLevel: {
      stringValue: 'ENABLED',
    },
    issuesAccessLevel: {
      stringValue: 'ENABLED',
    },
    forkingAccessLevel: {
      stringValue: 'ENABLED',
    },
    userPermissions: {
      removeProject: true,
      viewEditPage: true,
    },
    maxAccessLevel: {
      integerValue: 30,
    },
    __typename: 'Project',
  },
  {
    id: 'gid://gitlab/Project/1',
    fullPath: 'project/1',
    nameWithNamespace: 'Toolbox / Gitlab Smoke Tests',
    organizationEditPath: '/-/organizations/default/projects/toolbox/gitlab-smoke-tests/edit',
    webUrl: 'http://127.0.0.1:3000/toolbox/gitlab-smoke-tests',
    topics: [],
    forksCount: 0,
    avatarUrl: null,
    starCount: 0,
    visibility: 'internal',
    openMergeRequestsCount: 20,
    openIssuesCount: 34,
    descriptionHtml:
      '<p data-sourcepos="1:1-1:40" dir="auto">Veritatis error laboriosam libero autem.</p>',
    archived: false,
    mergeRequestsAccessLevel: {
      stringValue: 'ENABLED',
    },
    issuesAccessLevel: {
      stringValue: 'ENABLED',
    },
    forkingAccessLevel: {
      stringValue: 'ENABLED',
    },
    userPermissions: {
      removeProject: false,
      viewEditPage: true,
    },
    maxAccessLevel: {
      integerValue: 30,
    },
    __typename: 'Project',
  },
];

==> gitlab_17.0.8.orig.tar.bz2: gitlab-foss-v17.0.8/app/assets/javascripts/organizations/mock_projects.js <==
/* eslint-disable @gitlab/require-i18n-strings */

// This is temporary mock data that will be removed when completing the following:
// https://gitlab.com/gitlab-org/gitlab/-/issues/420777
// https://gitlab.com/gitlab-org/gitlab/-/issues/421441

export const organizationProjects = [
  {
    id: 'gid://gitlab/Project/8',
    fullPath: 'project/8',
    nameWithNamespace: 'Twitter / Typeahead.Js',
    organizationEditPath: '/-/organizations/default/projects/twitter/Typeahead.Js/edit',
    webUrl: 'http://127.0.0.1:3000/twitter/Typeahead.Js',
    topics: ['JavaScript', 'Vue.js', 'GraphQL', 'Jest', 'CSS', 'HTML'],
    forksCount: 4,
    avatarUrl: null,
    starCount: 0,
    visibility: 'public',
    openMergeRequestsCount: 5,
    openIssuesCount: 48,
    descriptionHtml:
      '<p data-sourcepos="1:1-1:59" dir="auto">Optio et reprehenderit enim doloremque deserunt et commodi. Sed sit amet iaculis neque. Morbi vel convallis elit. Aliquam vitae arcu orci. Aenean sem velit, dapibus eget enim id, tempor lobortis orci. Pellentesque dignissim nec velit eget sagittis. Maecenas lectus sapien, tincidunt ac cursus a, aliquam eu ipsum. Aliquam posuere maximus augue, ut vehicula elit vulputate condimentum. In libero leo, vehicula nec risus in, ullamcorper convallis risus. Phasellus sit amet lectus sit amet sem volutpat cursus. Nullam facilisis nulla nec lacus pretium, in pretium ex aliquam.</p>',
    archived: false,
    mergeRequestsAccessLevel: {
      stringValue: 'ENABLED',
    },
    issuesAccessLevel: {
      stringValue: 'ENABLED',
    },
    forkingAccessLevel: {
      stringValue: 'ENABLED',
    },
    userPermissions: {
      removeProject: true,
      viewEditPage: true,
    },
    maxAccessLevel: {
      integerValue: 30,
    },
    createdAt: '2023-09-19T14:42:38Z',
    updatedAt: '2024-04-24T03:47:38Z',
    __typename: 'Project',
  },
  {
    id: 'gid://gitlab/Project/7',
    fullPath: 'project/7',
    nameWithNamespace: 'Flightjs / Flight',
    organizationEditPath: '/-/organizations/default/projects/flightjs/Flight/edit',
    webUrl: 'http://127.0.0.1:3000/flightjs/Flight',
    topics: [],
    forksCount: 0,
    avatarUrl: null,
    starCount: 0,
    visibility: 'private',
    openMergeRequestsCount: 10,
    openIssuesCount: 37,
    descriptionHtml:
      '<p data-sourcepos="1:1-1:49" dir="auto">Dolor dicta rerum et ut eius voluptate earum qui.</p>',
    archived: false,
    mergeRequestsAccessLevel: {
      stringValue: 'ENABLED',
    },
    issuesAccessLevel: {
      stringValue: 'ENABLED',
    },
    forkingAccessLevel: {
      stringValue: 'ENABLED',
    },
    userPermissions: {
      removeProject: true,
      viewEditPage: true,
    },
    maxAccessLevel: {
      integerValue: 30,
    },
    createdAt: '2023-09-19T14:42:38Z',
    updatedAt: '2024-04-24T03:47:38Z',
    __typename: 'Project',
  },
  {
    id: 'gid://gitlab/Project/6',
    fullPath: 'project/6',
    nameWithNamespace: 'Jashkenas / Underscore',
    organizationEditPath: '/-/organizations/default/projects/jashkenas/Underscore/edit',
    webUrl: 'http://127.0.0.1:3000/jashkenas/Underscore',
    topics: [],
    forksCount: 0,
    avatarUrl: null,
    starCount: 0,
    visibility: 'private',
    openMergeRequestsCount: 0,
    openIssuesCount: 34,
    descriptionHtml:
      '<p data-sourcepos="1:1-1:52" dir="auto">Incidunt est aliquam autem nihil eveniet quis autem.</p>',
    archived: false,
    mergeRequestsAccessLevel: {
      stringValue: 'ENABLED',
    },
    issuesAccessLevel: {
      stringValue: 'ENABLED',
    },
    forkingAccessLevel: {
      stringValue: 'ENABLED',
    },
    userPermissions: {
      removeProject: true,
      viewEditPage: true,
    },
    maxAccessLevel: {
      integerValue: 30,
    },
    createdAt: '2023-09-19T14:42:38Z',
    updatedAt: '2024-04-24T03:47:38Z',
    __typename: 'Project',
  },
  {
    id: 'gid://gitlab/Project/5',
    fullPath: 'project/5',
    nameWithNamespace: 'Commit451 / Lab Coat',
    organizationEditPath: '/-/organizations/default/projects/Commit451/lab-coat/edit',
    webUrl: 'http://127.0.0.1:3000/Commit451/lab-coat',
    topics: [],
    forksCount: 0,
    avatarUrl: null,
    starCount: 0,
    visibility: 'internal',
    openMergeRequestsCount: 3,
    openIssuesCount: 49,
    descriptionHtml:
      '<p data-sourcepos="1:1-1:34" dir="auto">Sint eos dolorem impedit rerum et.</p>',
    archived: true,
    mergeRequestsAccessLevel: {
      stringValue: 'ENABLED',
    },
    issuesAccessLevel: {
      stringValue: 'ENABLED',
    },
    forkingAccessLevel: {
      stringValue: 'ENABLED',
    },
    userPermissions: {
      removeProject: true,
      viewEditPage: true,
    },
    maxAccessLevel: {
      integerValue: 30,
    },
    createdAt: '2023-09-19T14:42:38Z',
    updatedAt: '2024-04-24T03:47:38Z',
    __typename: 'Project',
  },
  {
    id: 'gid://gitlab/Project/1',
    fullPath: 'project/1',
    nameWithNamespace: 'Toolbox / Gitlab Smoke Tests',
    organizationEditPath: '/-/organizations/default/projects/toolbox/gitlab-smoke-tests/edit',
    webUrl: 'http://127.0.0.1:3000/toolbox/gitlab-smoke-tests',
    topics: [],
    forksCount: 0,
    avatarUrl: null,
    starCount: 0,
    visibility: 'internal',
    openMergeRequestsCount: 20,
    openIssuesCount: 34,
    descriptionHtml:
      '<p data-sourcepos="1:1-1:40" dir="auto">Veritatis error laboriosam libero autem.</p>',
    archived: false,
    mergeRequestsAccessLevel: {
      stringValue: 'ENABLED',
    },
    issuesAccessLevel: {
      stringValue: 'ENABLED',
    },
    forkingAccessLevel: {
      stringValue: 'ENABLED',
    },
    userPermissions: {
      removeProject: false,
      viewEditPage: true,
    },
    maxAccessLevel: {
      integerValue: 30,
    },
    createdAt: '2023-09-19T14:42:38Z',
    updatedAt: '2024-04-24T03:47:38Z',
    __typename: 'Project',
  },
];
